/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.api;

import java.net.InetAddress;

import org.ow2.petals.registry.client.api.exception.ConnectionErrorException;

/**
 * Interface of a Petals Registry Client.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface PetalsRegistryClient {

    /**
     * @return The IP address of the cluster member on which the client is connected.
     */
    public InetAddress getHost();

    /**
     * @return The TCP port of the cluster member on which the client is connected.
     */
    public int getPort();

    /**
     * @return The credential group name with which the client is connected.
     */
    public String getGroup();

    /**
     * Release the connection to the JMX server
     * 
     * @throws ConnectionErrorException
     */
    public void disconnect() throws ConnectionErrorException;

    /**
     * @return The topology service
     */
    public TopologyService getTopologyService();
}
