/**
 * Copyright (c) 2014-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.client.api;

import java.util.Map;

import org.ow2.petals.registry.client.api.exception.UnexistingTopologyException;
import org.ow2.petals.topology.generated.Topology;

/**
 * The service managing the topology information registered in the Petals Registry cluster
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public interface TopologyService {

    /**
     * @return All topology definitions registered
     */
    // TODO: The key should be a topology identifier composed of 2 attributes: domain and sub-domain
    public Map<String, Topology> getTopologies();

    /**
     * @param topologyId
     *            The topology identifier
     * @return The definition of the topology
     */
    public Topology getTopology(final String topologyId);

    /**
     * Clean all information associated to the given topology from the Petals Registry Overlay cluster.
     * 
     * @param domain
     *            Domain name of the topology to clean
     * @param subDomain
     *            Sub-domain name of the topology to clean
     * @throws UnexistingTopologyException
     *             The given topology does not exist in the Petals Registry Overlay cluster
     */
    public void clean(final String domain, final String subDomain) throws UnexistingTopologyException;
}
